@@ -496,6 +496,20 @@ static int s_test_socket_with_bind_to_invalid_interface(struct aws_allocator *al
 }
 AWS_TEST_CASE(test_socket_with_bind_to_invalid_interface, s_test_socket_with_bind_to_invalid_interface)
 
+static int s_test_is_network_interface_name_valid(struct aws_allocator *allocator, void *ctx) {
+    (void)ctx;
+    (void)allocator;
+
+    ASSERT_FALSE(aws_is_network_interface_name_valid("invalid_name"));
+#if defined(AWS_OS_LINUX)
+    ASSERT_TRUE(aws_is_network_interface_name_valid("lo"));
+#elif !defined(AWS_OS_WINDOWS)
+    ASSERT_TRUE(aws_is_network_interface_name_valid("lo0"));
+#endif
+    return AWS_OP_SUCCESS;
+}
+AWS_TEST_CASE(test_is_network_interface_name_valid, s_test_is_network_interface_name_valid)
+
 #if defined(USE_VSOCK)
 static int s_test_vsock_loopback_socket_communication(struct aws_allocator *allocator, void *ctx) {
 /* Without vsock loopback it's difficult to test vsock functionality.
